@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hakyll
 version: 4.7.5.1
-id: hakyll-4.7.5.1-3724481241875863af6c18eb2d026c93
-key: hakyl_Dzfl0Z5Hfhk1uSjpOmqzaQ
+id: hakyll-4.7.5.1-fa2ef4fc5779f252c143b6c71ce91e00
+key: hakyl_GlB0oYJSfEU54FfhImIDIF
 license: BSD3
 maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
 homepage: http://jaspervdj.be/hakyll
@@ -50,7 +50,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/hakyll-4.7.5.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/hakyll-4.7.5.1
-hs-libraries: HShakyll-4.7.5.1-Dzfl0Z5Hfhk1uSjpOmqzaQ
+hs-libraries: HShakyll-4.7.5.1-GlB0oYJSfEU54FfhImIDIF
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
@@ -64,14 +64,14 @@ depends:
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.8-7af4c72b658e9ba872144aa8bca2c27b
+    http-conduit-2.1.8-288436503dec7c7ed70373ac0e4730a6
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     lrucache-1.2.0.0-97fd799690b7e95999ded6be87e87c88
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
-    pandoc-1.16.0.2-b6635e89c036b6c1a009fe0e8c58734b
-    pandoc-citeproc-0.9-39d757811f1dcaf68e3c2fc4fa9a7619
+    pandoc-1.16.0.2-1e3210a759893e8cb19c047605eb93fb
+    pandoc-citeproc-0.9-82d758a0aade0504e63eea3491cf7af5
     parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
